import React from "react";
import axios from "axios";
import { useState, useEffect } from "react";
import { useNavigate} from "react-router-dom";
import './Noticias.css';

//Al momento la base de datos esta siendo accedida de manera local y esta en processo a ser accedido desde el servidor

export default function Noticias(){
    const navigate = useNavigate();

    const [inputs, setInputs] = useState([]);

    const handleSubmit = e => {
        e.preventDefault();
        e.persist();
        axios({
        method: 'post',
        headers: {
            'Accept':'application/json',
            'content-type': 'application/json'
        },
        url: `https://ada.uprrp.edu/~luis.ortiz79/api/user/save`,
        //data: formData
        data: inputs,
        body: JSON.stringify(inputs),
        })
        .then((response)=>response.json())
        .then((response)=>{
            console.log(response.data);
            navigate('/');
        })
        .catch((error)=>{
            alert("Error: " + error);
        });
    }

    const handleChange = (e) => {
        const name = e.target.name;
        const value = e.target.value;
        setInputs(values => ({
            ...values,
            [name]: value,
        }));
    }

    const [users, setUsers] = useState([]);
    useEffect(() => {
        getUsers();
    }, []);

    //Esta funcion busca el id de la noticia selecionada en la base de datos
    function getUsers() {
        axios({
            method: 'get',
            headers: {
                'Accept':'application/json',
                'content-type': 'application/json'
            },
            url: `https://ada.uprrp.edu/~luis.ortiz79/api/users/`,
            //data: formData
        })
        .then((response)=>response.json())
        .then((response)=>{
            console.log(response.data);
            setUsers(response.data);
        })
        .catch((error)=>{
            alert("Error: " + error);
        });
    }


    //Esta funcion envie el id a la base de datos para ser borrada
    const deleteUser = (id) => {
        axios({
            method: 'delete',
            headers: {
                'Accept':'application/json',
                'content-type': 'application/json'
            },
            url: `https://ada.uprrp.edu/~luis.ortiz79/api/user/${id}/delete`,
            //data: formData
        })
        .then((response)=>response.json())
        .then((response)=>{
            console.log(response.data);
            getUsers();
        })
        .catch((error)=>{
            alert("Error: " + error);
        });
    }

    //Crea el pop up window para asegura de que si el usuario quiere borrar la noticia o no
    const deleteConfirm = (id) => {
        if (window.confirm("Estas seguro que lo quieres borrar?")) {
          deleteUser(id);
        }
      };

    return (
        //En la primera tabla es donde el usuario puede subir la noticia en la base de datos
        //En la segunda tabla es donde le da la lista de lo que contiene la base de datos y la opcion de poder borrar esa noticia
        <div className="Noticias">
            <h1>Noticias</h1>

            <form onSubmit={handleSubmit}>
            <table cellSpacing="10">
                    <tbody>
                        <tr>
                            <th>
                                <label>Title:</label>
                            </th>
                            <td>
                                <input type="text" name="title" placeholder="Title for the news.." onChange={handleChange} />
                            </td>
                        </tr>
                        <tr>
                            <th>
                                <label>Subject:</label>
                            </th>
                            <td>
                                <textarea name="subject" placeholder="Write something.." onChange={handleChange} ></textarea>
                            </td>
                        </tr>
                        <tr>
                            <td colSpan="2" align ="right">
                                <input type="submit" value="Submit" />
                            </td>
                        </tr>
                    </tbody>
                </table>
            </form>

            <table>
                <thead>
                    <tr>
                        <th>#</th>
                        <th>Title</th>
                        <th>Subject</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    {users.map((user, key) =>
                        <tr key={key}>
                            <td>{user.id}</td>
                            <td>{user.title}</td>
                            <td>{user.subject}</td>
                            <td>
                                <input type="submit" value="Delete" onClick={() => deleteConfirm(user.id)} />
                            </td>
                        </tr>
                    )}

                </tbody>
            </table>
        </div>
    );
}
